==> aws-android-sdk-translate-2.27.0-sources.jar: com/amazonaws/services/translate/model/transform/ImportTerminologyResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.translate.model.transform;

import com.amazonaws.services.translate.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response ImportTerminologyResult
 */
public class ImportTerminologyResultJsonUnmarshaller implements
        Unmarshaller<ImportTerminologyResult, JsonUnmarshallerContext> {

    public ImportTerminologyResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        ImportTerminologyResult importTerminologyResult = new ImportTerminologyResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("TerminologyProperties")) {
                importTerminologyResult
                        .setTerminologyProperties(TerminologyPropertiesJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return importTerminologyResult;
    }

    private static ImportTerminologyResultJsonUnmarshaller instance;

    public static ImportTerminologyResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new ImportTerminologyResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-translate-2.69.0-sources.jar: com/amazonaws/services/translate/model/transform/ImportTerminologyResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.translate.model.transform;

import com.amazonaws.services.translate.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response ImportTerminologyResult
 */
public class ImportTerminologyResultJsonUnmarshaller implements
        Unmarshaller<ImportTerminologyResult, JsonUnmarshallerContext> {

    public ImportTerminologyResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        ImportTerminologyResult importTerminologyResult = new ImportTerminologyResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("TerminologyProperties")) {
                importTerminologyResult
                        .setTerminologyProperties(TerminologyPropertiesJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else if (name.equals("AuxiliaryDataLocation")) {
                importTerminologyResult
                        .setAuxiliaryDataLocation(TerminologyDataLocationJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return importTerminologyResult;
    }

    private static ImportTerminologyResultJsonUnmarshaller instance;

    public static ImportTerminologyResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new ImportTerminologyResultJsonUnmarshaller();
        return instance;
    }
}
